@@ -57,7 +57,8 @@ SUPPORTED_MESSAGE_FILE_TYPES: List[MessageType] = [
     MessageType.MESSAGE_TYPE_ATTACHMENT,
     MessageType.MESSAGE_TYPE_EMOTICON,
     MessageType.MESSAGE_TYPE_IMAGE,
-    MessageType.MESSAGE_TYPE_VIDEO
+    MessageType.MESSAGE_TYPE_VIDEO,
+    MessageType.MESSAGE_TYPE_AUDIO
 ]
 
 
@@ -83,7 +84,7 @@ class Message(Accessory[MessagePayload]):
     def message_type(self) -> MessageType:
         """
         get the message type
-        for more details, please refer to : https://github.com/Chatie/grpc/blob/master/proto/wechaty/puppet/message.proto#L9
+        for more details, please refer to : https://github.com/wechaty/grpc/blob/master/proto/wechaty/puppet/message.proto#L9
         """
         return self.payload.type
 
@@ -540,7 +541,12 @@ class Message(Accessory[MessagePayload]):
                 f'this type <{self.type().name}> message can"t be converted to '
                 f'FileBox'
             )
-        file_box = await self.puppet.message_file(self.message_id)
+        msg_type: MessageType = self.type()
+        if msg_type == MessageType.MESSAGE_TYPE_IMAGE:
+            file_box = await self.puppet.message_image(self.message_id)
+        else:
+            file_box = await self.puppet.message_file(self.message_id)
+        
         return file_box
 
     def to_image(self) -> Image:
