@@ -5,6 +5,7 @@ from __future__ import annotations
 
 from typing import (
     Type,
+    Union
 )
 import requests
 from lxml import etree  # type: ignore
@@ -31,21 +32,27 @@ class UrlLink:
     @classmethod
     def create(
         cls: Type[UrlLink],
-        url: str,
+        url: str, title: Union[str, None], thumbnail_url: Union[str, None], description: Union[str, None]
     ) -> UrlLink:
         """
         create urllink from url string
         """
         log.info('create url_link for %s', url)
         html = etree.HTML(requests.get(url).text)
-        title = html.xpath('//meta[@property="og:title"]/@content')
-        thumbnail_url = html.xpath('//meta[@property="og:image"]/@content')
-        description = html.xpath('//meta[@property="og:description"]/@content')
+        if title is None:
+            title = html.xpath('//meta[@property="og:title"]/@content')
+            title = title[0] if len(title) else url
+        if thumbnail_url is None:
+            thumbnail_url = html.xpath('//meta[@property="og:image"]/@content')
+            thumbnailUrl = thumbnail_url[0] if len(thumbnail_url) else ""
+        if description is None:
+            description = html.xpath('//meta[@property="og:description"]/@content')
+            description = description[0] if len(description) else ""
         payload = UrlLinkPayload(
-            title=title[0] if len(title) else url,
+            title=title,
             url=url,
-            thumbnailUrl=thumbnail_url[0] if len(thumbnail_url) else "",
-            description=description[0] if len(description) else ""
+            thumbnailUrl=thumbnail_url,
+            description=description
         )
         return UrlLink(payload)
 
